@@ -22,13 +22,18 @@ class Evaluator:
             return individual.loss_
         else:
             raise NotImplementedError()
-            # write loss value to individual
 
     def eval_all(self, individuals):
         """eval_all.
 
-        Evaluate individuals in a given iterable, return numpy array of loss values.
+        Evaluate individuals in a given iterable, return list of loss values.
 
         individuals: iterable containing Individuals.
         """
-        return [ self.eval(ind) for ind in individuals ]
+        losses = []
+        for ind in individuals:
+            if ind.loss_ is None:
+                loss = self.eval(ind)
+                ind.loss_ = loss
+            losses.append(ind.loss_)
+        return losses
